AdjustedArithmeticMeanRank
==========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedArithmeticMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRank.increasing
      ~AdjustedArithmeticMeanRank.name
      ~AdjustedArithmeticMeanRank.needs_candidates
      ~AdjustedArithmeticMeanRank.supported_rank_types
      ~AdjustedArithmeticMeanRank.synonyms
      ~AdjustedArithmeticMeanRank.value_range

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: synonyms
   .. autoattribute:: value_range
